@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -51,7 +51,7 @@ you can run tests in all supported runtimes::
 
     python etstool.py test-all
 
-Currently supported runtime values are ``3.6``.  Not all
+The only currently supported runtime values is ``3.8``.  Not all
 combinations of runtimes will work, but the tasks will fail with
 a clear error if that is the case.
 
@@ -61,10 +61,8 @@ a developer's purpose.
 Changing This File
 ------------------
 
-To change the packages installed during a test run, change the dependencies
-variable below.  To install a package from github, or one which is not yet
-available via EDM, add it to the `ci-src-requirements.txt` file (these will be
-installed by `pip`).
+To change the packages installed during a test run, change the
+``common_dependencies`` variable below.
 
 Other changes to commands should be a straightforward change to the listed
 commands for each task. See the EDM documentation for more information about
@@ -95,14 +93,22 @@ common_dependencies = {
     "enthought_sphinx_theme",
     "flake8",
     "flake8_ets",
-    "lark_parser",
-    "mypy",
     "numpy",
-    "pyqt5",
     "Sphinx",
+    "sphinx_copybutton",
     "traitsui",
 }
 
+# Dependencies on the Python runtime.
+runtime_dependencies = {
+    "3.8": {"pyside6"},
+}
+
+# Dependencies that need to be installed from PyPI
+pypi_dependencies = {
+    "3.8": {"lark-parser", "mypy"}
+}
+
 # Dependencies we install from source for testing
 source_dependencies = {"traitsui"}
 
@@ -111,8 +117,8 @@ unix_dependencies = {
     "gnureadline",
 }
 
-supported_runtimes = ["3.6"]
-default_runtime = "3.6"
+supported_runtimes = ["3.8"]
+default_runtime = "3.8"
 
 github_url_fmt = "git+http://github.com/enthought/{0}.git#egg={0}"
 
@@ -171,6 +177,7 @@ def install(edm, runtime, environment, editable, source):
     """
     parameters = get_parameters(edm, runtime, environment)
     dependencies = common_dependencies.copy()
+    dependencies.update(runtime_dependencies.get(runtime, set()))
     if sys.platform != "win32":
         dependencies.update(unix_dependencies)
 
@@ -191,6 +198,12 @@ def install(edm, runtime, environment, editable, source):
         install_stubs,
     ]
 
+    if pypi_dependencies:
+        commands += [
+            "{edm} run -e {environment} -- python -m pip install " + dep
+            for dep in pypi_dependencies.get(runtime, set())
+        ]
+
     click.echo("Creating environment '{environment}'".format(**parameters))
     execute(commands, parameters)
     if source:
