@@ -1,4 +1,4 @@
-# (C) Copyright 2020-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2020-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,14 +15,15 @@ from unittest import TestCase
 from traits.testing.optional_dependencies import (
     pkg_resources,
     requires_mypy,
+    requires_numpy_typing,
     requires_pkg_resources,
 )
 from traits_stubs_tests.util import MypyAssertions
 
 
+@requires_pkg_resources
 @requires_mypy
 class TestAnnotations(TestCase, MypyAssertions):
-    @requires_pkg_resources
     def test_all(self, filename_suffix=""):
         """ Run mypy for all files contained in traits_stubs_tests/examples
         directory.
@@ -41,3 +42,23 @@ class TestAnnotations(TestCase, MypyAssertions):
         for file_path in examples_dir.glob("*{}.py".format(filename_suffix)):
             with self.subTest(file_path=file_path):
                 self.assertRaisesMypyError(file_path)
+
+    @requires_numpy_typing
+    def test_numpy_examples(self):
+        """ Run mypy for files contained in traits_stubs_tests/numpy_examples
+        directory.
+
+        Lines with expected errors are marked inside these files.
+        Any mismatch will raise an assertion error.
+
+        Parameters
+        ----------
+        filename_suffix: str
+            Optional filename suffix filter.
+        """
+        examples_dir = Path(pkg_resources.resource_filename(
+            'traits_stubs_tests', 'numpy_examples'))
+
+        for file_path in examples_dir.glob("*.py"):
+            with self.subTest(file_path=file_path):
+                self.assertRaisesMypyError(file_path)
