@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -13,7 +13,14 @@ import operator
 import pickle
 import unittest.mock
 
-from traits.api import HasTraits, Int, List
+from traits.api import (
+    DefaultValue,
+    HasTraits,
+    Int,
+    List,
+    TraitType,
+    ValidateTrait,
+)
 from traits.testing.optional_dependencies import numpy, requires_numpy
 from traits.trait_base import _validate_everything
 from traits.trait_errors import TraitError
@@ -1457,3 +1464,36 @@ class TestTraitListObject(unittest.TestCase):
         self.assertEqual(list_object, [1, 2, 3, 4, 5])
         with self.assertRaises(TraitError):
             list_object.append(4)
+
+    def test_disconnected_list(self):
+        # Objects that are disconnected from their HasTraits "owner" can arise
+        # as a result of clone_traits operations, or of serialization and
+        # deserialization.
+        disconnected = TraitListObject(
+            trait=List(Int),
+            object=None,
+            name="foo",
+            value=[1, 2, 3],
+        )
+        self.assertEqual(disconnected.object(), None)
+
+    def test_item_validation_uses_ctrait(self):
+        # Regression test for enthought/traits#1619
+
+        class RangeInstance(TraitType):
+            default_value_type = DefaultValue.constant
+
+            default_value = range(10)
+
+            fast_validate = ValidateTrait.coerce, range
+
+        class HasRanges(HasTraits):
+            ranges = List(RangeInstance())
+
+        obj = HasRanges()
+
+        with self.assertRaises(TraitError):
+            obj.ranges.append(23)
+
+        obj.ranges.append(range(10, 20))
+        self.assertEqual(obj.ranges, [range(10, 20)])
