@@ -1,3 +1,13 @@
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 """ Tests for dynamic notifiers with `dispatch='ui'`.
 
 Dynamic notifiers created with the `dispatch='ui'` option dispatch event
@@ -11,14 +21,18 @@ At present, `dispatch='ui'` and `dispatch='fast_ui'` have the same effect.
 
 """
 
+import threading
+import time
+import unittest
+
 # Preamble: Try importing Qt, and set QT_FOUND to True on success.
 try:
-    from pyface.util.guisupport import get_app_qt4, start_event_loop_qt4
+    from pyface.util.guisupport import get_app_qt4
 
     # This import is necessary to set the `ui_handler` global variable in
     # `traits.trait_notifiers`, which is responsible for dispatching the events
     # to the UI thread.
-    from traitsui.qt4 import toolkit
+    from traitsui.qt4 import toolkit  # noqa: F401
 
     qt4_app = get_app_qt4()
 
@@ -29,14 +43,8 @@ else:
     QT_FOUND = True
 
 
-import thread
-from threading import Thread
-import time
-
-from traits.api import Callable, Float, HasTraits, on_trait_change
-from traits.testing.unittest_tools import unittest
-
 from traits import trait_notifiers
+from traits.api import Callable, Float, HasTraits, on_trait_change
 
 
 class CalledAsMethod(HasTraits):
@@ -48,7 +56,7 @@ class CalledAsDecorator(HasTraits):
 
     callback = Callable
 
-    @on_trait_change('foo', dispatch='ui')
+    @on_trait_change("foo", dispatch="ui")
     def on_foo_change(self, obj, name, old, new):
         self.callback(obj, name, old, new)
 
@@ -70,14 +78,15 @@ class BaseTestUINotifiers(object):
         qt4_app.processEvents()
 
     def on_foo_notifications(self, obj, name, old, new):
-        thread_id = thread.get_ident()
+        thread_id = threading.current_thread().ident
         event = (thread_id, (obj, name, old, new))
         self.notifications.append(event)
 
     #### Tests ################################################################
 
     @unittest.skipIf(
-        not QT_FOUND, "Qt event loop not found, UI dispatch not possible.")
+        not QT_FOUND, "Qt event loop not found, UI dispatch not possible."
+    )
     def test_notification_from_main_thread(self):
 
         obj = self.obj_factory()
@@ -89,13 +98,14 @@ class BaseTestUINotifiers(object):
         self.assertEqual(len(notifications), 1)
 
         thread_id, event = notifications[0]
-        self.assertEqual(event, (obj, 'foo', 0, 3))
+        self.assertEqual(event, (obj, "foo", 0, 3))
 
         ui_thread = trait_notifiers.ui_thread
         self.assertEqual(thread_id, ui_thread)
 
     @unittest.skipIf(
-        not QT_FOUND, "Qt event loop not found, UI dispatch not possible.")
+        not QT_FOUND, "Qt event loop not found, UI dispatch not possible."
+    )
     def test_notification_from_separate_thread(self):
 
         obj = self.obj_factory()
@@ -104,7 +114,7 @@ class BaseTestUINotifiers(object):
         def set_foo_to_3(obj):
             obj.foo = 3
 
-        Thread(target=set_foo_to_3, args=(obj,)).start()
+        threading.Thread(target=set_foo_to_3, args=(obj,)).start()
 
         # Wait for a while to make sure the function has finished.
         time.sleep(0.1)
@@ -115,7 +125,7 @@ class BaseTestUINotifiers(object):
         self.assertEqual(len(notifications), 1)
 
         thread_id, event = notifications[0]
-        self.assertEqual(event, (obj, 'foo', 0, 3))
+        self.assertEqual(event, (obj, "foo", 0, 3))
 
         ui_thread = trait_notifiers.ui_thread
         self.assertEqual(thread_id, ui_thread)
@@ -127,7 +137,7 @@ class TestMethodUINotifiers(BaseTestUINotifiers, unittest.TestCase):
 
     def obj_factory(self):
         obj = CalledAsMethod()
-        obj.on_trait_change(self.on_foo_notifications, 'foo', dispatch='ui')
+        obj.on_trait_change(self.on_foo_notifications, "foo", dispatch="ui")
         return obj
 
 
@@ -136,7 +146,3 @@ class TestDecoratorUINotifiers(BaseTestUINotifiers, unittest.TestCase):
 
     def obj_factory(self):
         return CalledAsDecorator(callback=self.on_foo_notifications)
-
-
-if __name__ == '__main__':
-    unittest.main()
