@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -548,7 +548,8 @@ class TraitListObject(TraitList):
     trait : CTrait
         The trait that the list has been assigned to.
     object : HasTraits
-        The object the list belongs to.
+        The object this list belongs to. Can also be None in cases where the
+        list has been disconnected from its HasTraits parent.
     name : str
         The name of the trait on the object.
     value : iterable
@@ -558,8 +559,9 @@ class TraitListObject(TraitList):
     ----------
     trait : CTrait
         The trait that the list has been assigned to.
-    object : HasTraits
-        The object the list belongs to.
+    object : callable
+        A callable that when called with no arguments returns the HasTraits
+        object that this list belongs to, or None if there is no such object.
     name : str
         The name of the trait on the object.
     value : iterable
@@ -569,7 +571,7 @@ class TraitListObject(TraitList):
     def __init__(self, trait, object, name, value):
 
         self.trait = trait
-        self.object = ref(object)
+        self.object = (lambda: None) if object is None else ref(object)
         self.name = name
         self.name_items = None
         if trait.has_items:
@@ -812,7 +814,7 @@ class TraitListObject(TraitList):
         """
         return TraitListObject(
             self.trait,
-            lambda: None,
+            None,
             self.name,
             [copy.deepcopy(x, memo) for x in self],
         )
@@ -857,7 +859,7 @@ class TraitListObject(TraitList):
         if object is None:
             return value
 
-        trait_validator = self.trait.item_trait.handler.validate
+        trait_validator = self.trait.item_trait.validate
         if trait_validator is None:
             return value
 
